<?php
/**
 * Plugin Name:       Future SMS | WinSMS Buddy For WooCommerce
 * Plugin URI:        https://futurestarsmedia.co.za/future-sms-win-sms-buddy/
 * Description:       Integrate WinSMS with WooCommerce to send SMS notifications for order updates and new orders.
 * Version:           1.0.0
 * Requires at least: 5.2
 * Requires PHP:      7.2
 * Author:            Future Stars Media (PTY) Ltd
 * Author URI:        https://www.futurestarsmedia.co.za/
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Update URI:       https://futurestarsmedia.co.za/future-sms-win-sms-buddy/
 * Text Domain:       future-sms-win-sms-buddy
 * Domain Path:       /languages
 * Logo:        plugin-logo.pngs
 */

// Plugin code goes here

// Thank you notification
add_action('admin_notices', 'future_sms_win_sms_buddy_thank_you_notification');
function future_sms_win_sms_buddy_thank_you_notification()
{
    $current_screen = get_current_screen();
    if ($current_screen->parent_base === 'plugins' && $current_screen->id === 'plugins') {
        ?>
        <div class="notice notice-success is-dismissible">
            <p><?php _e('Thank you for installing Future SMS | WinSMS Buddy For WooCommerce!', 'future-sms-win-sms-buddy'); ?></p>
        </div>
        <?php
    }
}

// Plugin settings page
function future_sms_win_sms_buddy_settings_page()
{
    $username = get_option('future_sms_win_sms_buddy_username');
    $password = get_option('future_sms_win_sms_buddy_password');
    $enable_sms = get_option('future_sms_win_sms_buddy_enable_sms');
    $enable_order_status_update_sms = get_option('future_sms_win_sms_buddy_enable_order_status_update_sms');
    $enable_new_order_sms = get_option('future_sms_win_sms_buddy_enable_new_order_sms');
    $enable_admin_notifications = get_option('future_sms_win_sms_buddy_enable_admin_notifications');
    $admin_notification_number = get_option('future_sms_win_sms_buddy_admin_notification_number');
    ?>

    <div class="wrap">
        <h1>Future SMS | WinSMS Buddy Settings</h1>
        <p>Settings Dasboard to Configure the settings for the Future SMS | WinSMS Buddy plugin.</p>
		<p><b>Powered by Future Stars Media(PTY)ltd | info@futurestarsmedia.co.za.</b></p>

        <h2 class="nav-tab-wrapper">
            <a href="#" class="nav-tab nav-tab-active">Instructions</a>
            <a href="#" class="nav-tab">General</a>
            <a href="#" class="nav-tab">Order Status Update</a>
            <a href="#" class="nav-tab">New Order Notifications</a>
            <a href="#" class="nav-tab">Admin Notifications</a>
            <a href="#" class="nav-tab">Plugin Developers</a>
        </h2>

        <form method="post" action="options.php">

            <div id="instructions-settings" class="settings-tab">
                <h2>Instructions</h2>
                <p>To use this plugin, you need to create a WinSMS account. Click <a href="https://www.winsms.co.za/buddy">here</a> to create a WinSMS account and Buy SMS Credits.</p>
                <a href="https://www.winsms.co.za/buddy"><img src="https://www.winsms.co.za/banner/winsmsaff4.gif" width="468" height="60" border="0"></a>
            </div>

            <div id="general-settings" class="settings-tab" style="display:none;">
                <h2>General Settings</h2>
                <table class="form-table">
                    <tr valign="top">
                        <th scope="row">Win SMS Username</th>
                        <td>
                            <input type="text" name="future_sms_win_sms_buddy_username" value="<?php echo esc_attr($username); ?>" class="regular-text" />
                        </td>
                    </tr>
                    <tr valign="top">
                        <th scope="row">Win SMS Password</th>
                        <td>
                            <input type="password" name="future_sms_win_sms_buddy_password" value="<?php echo esc_attr($password); ?>" class="regular-text" />
                        </td>
                    </tr>
                    <tr valign="top">
                        <th scope="row">Enable SMS Notifications</th>
                        <td>
                            <input type="checkbox" name="future_sms_win_sms_buddy_enable_sms" value="1" <?php checked($enable_sms, 1); ?> />
                        </td>
                    </tr>
                </table>
            </div>

            <div id="order-status-update-settings" class="settings-tab" style="display:none;">
                <h2>Order Status Update Settings</h2>
                <table class="form-table">
                    <tr valign="top">
                        <th scope="row">Enable Order Status Update SMS</th>
                        <td>
                            <input type="checkbox" name="future_sms_win_sms_buddy_enable_order_status_update_sms" value="1" <?php checked($enable_order_status_update_sms, 1); ?> />
                        </td>
                    </tr>
                </table>
            </div>

            <div id="new-order-notifications-settings" class="settings-tab" style="display:none;">
                <h2>New Order Notifications Settings</h2>
                <table class="form-table">
                    <tr valign="top">
                        <th scope="row">Enable New Order Notifications SMS</th>
                        <td>
                            <input type="checkbox" name="future_sms_win_sms_buddy_enable_new_order_sms" value="1" <?php checked($enable_new_order_sms, 1); ?> />
                        </td>
                    </tr>
                </table>
            </div>

            <div id="admin-notifications-settings" class="settings-tab" style="display:none;">
                <h2>Admin Notifications Settings</h2>
                <table class="form-table">
                    <tr valign="top">
                        <th scope="row">Enable Admin Notifications SMS</th>
                        <td>
                            <input type="checkbox" name="future_sms_win_sms_buddy_enable_admin_notifications" value="1" <?php checked($enable_admin_notifications, 1); ?> />
                        </td>
                    </tr>
                    <tr valign="top">
                        <th scope="row">Admin Notification Number</th>
                        <td>
                            <input type="text" name="future_sms_win_sms_buddy_admin_notification_number" value="<?php echo esc_attr($admin_notification_number); ?>" class="regular-text" />
                        </td>
                    </tr>
                </table>
            </div>

            <div id="plugin-developers-settings" class="settings-tab" style="display:none;">
                <h2>Plugin Developers</h2>
                <p>Future SMS | WinSMS Buddy is proudly developed by Future Stars Media (PTY) Ltd.</p>
                <p>Contact us:</p>
                <p>Website: <a href="http://www.futurestarsmedia.co.za">www.futurestarsmedia.co.za</a></p>
                <p>Email: <a href="mailto:support@futurestarsmedia.co.za">support@futurestarsmedia.co.za</a></p>
                <p>Tel: +27 12 054 5633 | +27 12 880 2925</p>
            </div>

            <?php settings_fields('future_sms_win_sms_buddy_settings_group'); ?>
            <?php do_settings_sections('future-sms-win-sms-buddy-settings'); ?>

            <?php submit_button(); ?>

        </form>

        <script type="text/javascript">
            document.addEventListener("DOMContentLoaded", function() {
                var tabLinks = document.querySelectorAll(".nav-tab");
                var tabContents = document.querySelectorAll(".settings-tab");

                function showTab(index) {
                    tabLinks.forEach(function(tab, tabIndex) {
                        tab.classList.remove("nav-tab-active");
                        tabContents[tabIndex].style.display = "none";
                    });

                    tabLinks[index].classList.add("nav-tab-active");
                    tabContents[index].style.display = "block";
                }

                tabLinks.forEach(function(tab, index) {
                    tab.addEventListener("click", function(e) {
                        e.preventDefault();
                        showTab(index);
                    });
                });

                showTab(0);
            });
        </script>
    </div>
<?php
}

// Register settings
add_action('admin_init', 'future_sms_win_sms_buddy_register_settings');
function future_sms_win_sms_buddy_register_settings()
{
    register_setting('future_sms_win_sms_buddy_settings_group', 'future_sms_win_sms_buddy_username');
    register_setting('future_sms_win_sms_buddy_settings_group', 'future_sms_win_sms_buddy_password');
    register_setting('future_sms_win_sms_buddy_settings_group', 'future_sms_win_sms_buddy_enable_sms');
    register_setting('future_sms_win_sms_buddy_settings_group', 'future_sms_win_sms_buddy_enable_order_status_update_sms');
    register_setting('future_sms_win_sms_buddy_settings_group', 'future_sms_win_sms_buddy_enable_new_order_sms');
    register_setting('future_sms_win_sms_buddy_settings_group', 'future_sms_win_sms_buddy_enable_admin_notifications');
    register_setting('future_sms_win_sms_buddy_settings_group', 'future_sms_win_sms_buddy_admin_notification_number');
}

// Add menu item
add_action('admin_menu', 'future_sms_win_sms_buddy_add_menu');
function future_sms_win_sms_buddy_add_menu()
{
    add_menu_page('Future SMS | Win SMS Buddy', 'Future SMS | Win SMS Buddy', 'manage_options', 'future-sms-win-sms-buddy-settings', 'future_sms_win_sms_buddy_settings_page');
}

// Send SMS notification on order status update
add_action('woocommerce_order_status_changed', 'future_sms_win_sms_buddy_send_order_status_update_sms', 10, 4);
function future_sms_win_sms_buddy_send_order_status_update_sms($order_id, $old_status, $new_status, $order)
{
    $enable_sms = get_option('future_sms_win_sms_buddy_enable_sms');
    $enable_order_status_update_sms = get_option('future_sms_win_sms_buddy_enable_order_status_update_sms');

    if ($enable_sms && $enable_order_status_update_sms && $new_status != $old_status) {
        $username = get_option('future_sms_win_sms_buddy_username');
        $password = get_option('future_sms_win_sms_buddy_password');

        $customer_name = $order->get_billing_first_name();
        $site_name = get_bloginfo('name');
        $order_number = $order->get_order_number();

        $message = "Hi $customer_name, your $site_name order number $order_number has been updated to $new_status.";

        future_sms_win_sms_buddy_send_sms($username, $password, $message, $order->get_billing_phone());
    }
}

// Send SMS notification on new order
add_action('woocommerce_new_order', 'future_sms_win_sms_buddy_send_new_order_sms');
function future_sms_win_sms_buddy_send_new_order_sms($order_id)
{
    $enable_sms = get_option('future_sms_win_sms_buddy_enable_sms');
    $enable_new_order_sms = get_option('future_sms_win_sms_buddy_enable_new_order_sms');

    if ($enable_sms && $enable_new_order_sms) {
        $username = get_option('future_sms_win_sms_buddy_username');
        $password = get_option('future_sms_win_sms_buddy_password');

        $order = wc_get_order($order_id);
        $customer_name = $order->get_billing_first_name();
        $site_name = get_bloginfo('name');
        $order_number = $order->get_order_number();
        $order_status = $order->get_status();

        $message = "Hi $customer_name, your $site_name order number $order_number has been updated to $order_status.";

        future_sms_win_sms_buddy_send_sms($username, $password, $message, $order->get_billing_phone());
    }
}

// Send SMS notification to admin
add_action('woocommerce_new_order', 'future_sms_win_sms_buddy_send_admin_notification_sms');
function future_sms_win_sms_buddy_send_admin_notification_sms($order_id)
{
    $enable_sms = get_option('future_sms_win_sms_buddy_enable_sms');
    $enable_admin_notifications = get_option('future_sms_win_sms_buddy_enable_admin_notifications');
    $admin_notification_number = get_option('future_sms_win_sms_buddy_admin_notification_number');

    if ($enable_sms && $enable_admin_notifications && $admin_notification_number) {
        $username = get_option('future_sms_win_sms_buddy_username');
        $password = get_option('future_sms_win_sms_buddy_password');

        $order = wc_get_order($order_id);
        $customer_name = $order->get_billing_first_name();
        $site_name = get_bloginfo('name');
        $order_number = $order->get_order_number();
        $order_status = $order->get_status();

        $message = "New order received on $site_name. Order number $order_number, Status: $order_status.";

        future_sms_win_sms_buddy_send_sms($username, $password, $message, $admin_notification_number);
    }
}

// Send SMS
function future_sms_win_sms_buddy_send_sms($username, $password, $message, $phone_number)
{
    $api_url = 'https://www.winsms.co.za/api/batchmessage.asp';
    $api_url .= '?User=' . urlencode($username);
    $api_url .= '&Password=' . urlencode($password);
    $api_url .= '&Message=' . urlencode($message);
    $api_url .= '&Numbers=' . urlencode($phone_number);

    wp_remote_get($api_url);
}
